@@ -256,7 +256,7 @@ class SQL:
 
         # FROM clause
         if th.foreign_keys:
-            sql_parts["FROM"].append(f"{th.quote(table)} AS {th.quote(alias)}")
+            sql_parts["FROM"].append(f"{TableHelper.quote(table)} AS {TableHelper.quote(alias)}")
             # Handle joins
             done = []
             for key, ref_info in th.foreign_keys.items():
@@ -270,11 +270,11 @@ class SQL:
                 ):
                     raise ValueError(f"Invalid table alias info for {ref_table}.")
                 sql_parts["FROM"].append(
-                    f"LEFT JOIN {th.quote(ref_table)} AS {th.quote(ref_info['alias'])} "
-                    f"ON {th.quote(alias)}.{th.quote(ref_info['local_column'])} = {th.quote(ref_info['alias'])}.{th.quote(ref_info['ref_column'])}"
+                    f"LEFT JOIN {TableHelper.quote(ref_table)} AS {TableHelper.quote(ref_info['alias'])} "
+                    f"ON {TableHelper.quote(alias)}.{TableHelper.quote(ref_info['local_column'])} = {TableHelper.quote(ref_info['alias'])}.{TableHelper.quote(ref_info['ref_column'])}"
                 )
         else:
-            sql_parts["FROM"].append(th.quote(table))
+            sql_parts["FROM"].append(TableHelper.quote(table))
 
         # WHERE
         if where:
@@ -446,7 +446,7 @@ class SQL:
         else:
             sql_parts = []
             sql_parts.append("UPDATE")
-            sql_parts.append(th.quote(table))
+            sql_parts.append(TableHelper.quote(table))
             sql_parts.append("SET " + ", ".join(set_clauses))
             if where_clauses:
                 sql_parts.append("WHERE " + " AND ".join(where_clauses))
