@@ -534,8 +534,10 @@ class TableHelper:
                     
         return " ".join(sql_parts), tuple(vals)
 
-    def quote(self, data: Union[str, List[str]]) -> Union[str, List[str]]:
+    @classmethod
+    def quote(cls, data: Union[str, List[str]]) -> Union[str, List[str]]:
         """
+        Class method version of quote for backward compatibility.
         Quotes identifiers (columns/tables) if needed, especially if they match reserved words or contain special chars.
         
         Args:
@@ -545,7 +547,7 @@ class TableHelper:
             Quoted identifier(s)
         """
         if isinstance(data, list):
-            return [self.quote(item) for item in data]
+            return [cls.quote(item) for item in data]
 
         if not isinstance(data, str):
             raise ValueError(f"Data must be string or list, got {type(data)}")
@@ -565,7 +567,7 @@ class TableHelper:
             if part.startswith('"') and part.endswith('"'):
                 quoted_parts.append(part)
             # Quote if reserved word, contains special chars, or starts with digit
-            elif (part.upper() in self.reserved or 
+            elif (part.upper() in cls.reserved or 
                   re.search(r'[/\-\s]', part) or 
                   (part and part[0].isdigit())):
                 # Escape any existing quotes in the identifier
